aboutsummaryrefslogtreecommitdiff
path: root/lib/csapi/receipts.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/csapi/receipts.h')
-rw-r--r--lib/csapi/receipts.h53
1 files changed, 28 insertions, 25 deletions
diff --git a/lib/csapi/receipts.h b/lib/csapi/receipts.h
index 47e2f3c7..1fac0acf 100644
--- a/lib/csapi/receipts.h
+++ b/lib/csapi/receipts.h
@@ -6,30 +6,33 @@
#include "jobs/basejob.h"
-#include <QtCore/QJsonObject>
+namespace Quotient {
-namespace QMatrixClient
-{
- // Operations
+/*! \brief Send a receipt for the given event ID.
+ *
+ * This API updates the marker for the given receipt type to the event ID
+ * specified.
+ */
+class PostReceiptJob : public BaseJob {
+public:
+ /*! \brief Send a receipt for the given event ID.
+ *
+ * \param roomId
+ * The room in which to send the event.
+ *
+ * \param receiptType
+ * The type of receipt to send.
+ *
+ * \param eventId
+ * The event ID to acknowledge up to.
+ *
+ * \param receipt
+ * Extra receipt information to attach to ``content`` if any. The
+ * server will automatically set the ``ts`` field.
+ */
+ explicit PostReceiptJob(const QString& roomId, const QString& receiptType,
+ const QString& eventId,
+ const QJsonObject& receipt = {});
+};
- /// Send a receipt for the given event ID.
- ///
- /// This API updates the marker for the given receipt type to the event ID
- /// specified.
- class PostReceiptJob : public BaseJob
- {
- public:
- /*! Send a receipt for the given event ID.
- * \param roomId
- * The room in which to send the event.
- * \param receiptType
- * The type of receipt to send.
- * \param eventId
- * The event ID to acknowledge up to.
- * \param receipt
- * Extra receipt information to attach to ``content`` if any. The
- * server will automatically set the ``ts`` field.
- */
- explicit PostReceiptJob(const QString& roomId, const QString& receiptType, const QString& eventId, const QJsonObject& receipt = {});
- };
-} // namespace QMatrixClient
+} // namespace Quotient